// VinciaMGInterface.h is a part of the VINCIA plug-in to the PYTHIA 8 generator.
// Copyright (C) 2010 W.T. Giele, D.A. Kosower, P.Z. Skands.
// VINCIA is licenced under the GNU GPL version 2.
// Please respect the MCnet Guidelines for Event Generator Authors and Users, 
//               http://www.montecarlonet.org/GUIDELINES

// Functions to interface to matrix elements generated with MadGraph
#ifndef VINCIA_MGInterface_H
#define VINCIA_MGInterface_H

// Include Pythia and headers
#include "Basics.h"
#include "Event.h"
#include "Info.h"
#include "ParticleData.h"
#include "PythiaStdlib.h"
#include "Settings.h"
#include "StandardModel.h"

// Include Vincia Standard Library
#include "VinciaCommon.h"

// Stdlib header for complex numbers.
#include <complex>

using namespace Pythia8;

// Function to initialize MadGraph Interface. 
// Returns false if MadGraph dummy library linked, true otherwise.

namespace Vincia {

  class MGInterface {

  public:

    // Constructor.
    MGInterface() {isInitPtr=false; isInit=false;};
    
    // Destructor
    virtual ~MGInterface() {};

    // Set pointers to required PYTHIA 8 objects
    void initPtr(CoupSM* coupSMPtrIn, ParticleData* particleDataPtrIn, 
		 Settings* settingsPtrIn) {
      coupSMPtr       = coupSMPtrIn;
      particleDataPtr = particleDataPtrIn;
      settingsPtr     = settingsPtrIn;
      isInitPtr       = true;
    }
    
    // Initialization routine. Must be called for anything to work.
    bool init();

    // Wrapper to set a parameter in a MadGraph common block
    void setParm(string which, double what);
    void setParm(string which, std::complex<double> what);
    
    // Wrapper to MadGraph matrix elements 
    // (should return -1 if relevant ME not implemented)
    double ME2(int nIn, vector<int> id, vector<Vec4> p);
    
    // Set verbose level
    void setVerbose(int verboseIn) {verbose = verboseIn;}

  private:
    
    // Is initialized?
    bool isInitPtr, isInit;

    // Pointers to PYTHIA 8 objects
    CoupSM*       coupSMPtr;
    ParticleData* particleDataPtr;
    Settings*     settingsPtr;

    // Color Mode (0: full color, 1: leading color)
    int colorDepth;

    // Verbose level
    int           verbose;

  };

}
#endif

