{

  // Which curves to show
  int plotNum=1;

  //Plot Settings
  bool logy=true;
  bool showGrid=false;
  double xMin = -3.0;
  double xMax =  0.0;
  double yMin = 0.1;
  double yMax = 100.0;
  string styleAna="same,c";
  string styleNum="same";

  // Title settings
  string processTit="Z#rightarrowq#bar{q}";
  string globalTit="Quark fragmentation function D(x)";
  string title = " ";
  string xtitle = "Log_{10}(1-x)";
  string ytitle = "D(x,Q_{0},Q_{IR})";

  // Legend settings
  string align="R";
  string alignLeg="L";
  double xLeg=0.16;
  if (alignLeg == "R") xLeg=0.49;
  double xSubTit=0.16;
  if (align == "R") xSubTit=0.65;
  double xLegEnd=xLeg+0.5;
  double xSubTitEnd=xSubTit+0.34;  

  // Define colors
  Int_t cWhite;   // for color index setting
  cWhite = TColor::GetColor("#fffffd");
  Int_t cShade;   // for color index setting
  cShade = TColor::GetColor("#ffff00");
  
  //Define borders and axes

  c1 = new TCanvas("c1","Vincia Plot Macro",100,10,500,500);
  gStyle->SetOptStat(0);
  if (showGrid) c1->SetGrid();  
  if (logy) c1->SetLogy();
  c1->SetFillColor(0);
  c1->SetBorderMode(0);
  c1->SetBorderSize(0);
  if (showGrid) {
    c1->SetGridx();
    c1->SetGridy();
  }
  c1->SetTickx();
  c1->SetTicky();
  c1->SetLeftMargin(0.133449);
  c1->SetRightMargin(0.025);
  c1->SetBottomMargin(0.12);
  c1->SetTopMargin(0.025);
  c1->SetFrameLineWidth(2);
  c1->SetFrameLineWidth(2);
  
  TH2D *axeshisto = new TH2D("axeshisto",title.c_str(),2,xMin,xMax,2,yMin,yMax);
  axeshisto->SetStats(0);
  axeshisto->GetXaxis()->SetTitle(xtitle.c_str());
  axeshisto->GetXaxis()->SetNdivisions(505);
  axeshisto->GetXaxis()->SetLabelFont(42);
  axeshisto->GetXaxis()->SetLabelSize(0.044);
  axeshisto->GetXaxis()->SetTitleSize(0.044);
  axeshisto->GetXaxis()->SetTitleFont(42);
  axeshisto->GetYaxis()->SetTitle(ytitle.c_str());
  axeshisto->GetYaxis()->SetNdivisions(508);
  axeshisto->GetYaxis()->SetLabelFont(42);
  axeshisto->GetYaxis()->SetLabelSize(0.044);
  axeshisto->GetYaxis()->SetTitleSize(0.044);
  axeshisto->GetYaxis()->SetLabelOffset(0.01);
  axeshisto->GetYaxis()->SetTitleOffset(1.4);
  axeshisto->GetYaxis()->SetTitleFont(42);
  axeshisto->SetTitle("");
  axeshisto->Draw();

  // File names
  string base="vc01uord";
  string sMaxName=base+"-glb-ev2-kin1-had2.14-max-ord-p4.3.root";
  string sMedName=base+"-glb-ev2-kin1-had2.14-med-ord-p4.3.root";
  string sDefName=base+"-glb-ev2-kin1-had2.14-def-ord-p4.3.root";
  string sAriName=base+"-glb-ev2-kin1-had2.14-ari-ord-p4.3.root";
  string sMinName=base+"-glb-ev2-kin1-had2.14-min-ord-p4.3.root";
  string spTName=base+"-glb-ev1-kin1-had2.14-def-ord-p4.3.root";
  string spT2Name=base+"-glb-ev1-kin1-had1.10-def-ord-p4.3.root";
  string sPytName="py01uord.3.root";
  string sE2Name=base+"-glb-ev2-kin1-had2.14-def-ord-p4.2.root";
  string sE4Name=base+"-glb-ev2-kin1-had2.14-def-ord-p4.4.root";
  
  // Open files and move to dummy directory
  TFile vcmin(sMinName.c_str());
  TFile vcdef(sDefName.c_str());
  TFile vcari(sAriName.c_str());
  TFile vcmax(sMaxName.c_str());
  TFile vcpT(spTName.c_str());
  TFile vcpT2(spT2Name.c_str());
  TFile vcE2(sE2Name.c_str());
  TFile vcE4(sE4Name.c_str());
  TFile pyt(sPytName.c_str());
  TFile mydum("dum.root");
  
  // Open histograms
  string Hana="DLogA";
  string Hnum="DLogN";
  TH1F Tana = *(TH1F*)vcdef.Get(Hana.c_str());
  TH1F Tdef = *(TH1F*)vcdef.Get(Hnum.c_str());
  TH1F TpT = *(TH1F*)vcpT.Get(Hnum.c_str());
  TH1F TpT2 = *(TH1F*)vcpT2.Get(Hnum.c_str());
  TH1F Tmin = *(TH1F*)vcmin.Get(Hnum.c_str());
  TH1F Tari = *(TH1F*)vcari.Get(Hnum.c_str());
  TH1F Tmax = *(TH1F*)vcmax.Get(Hnum.c_str());
  TH1F TE2 = *(TH1F*)vcE2.Get(Hnum.c_str());
  TH1F TE4 = *(TH1F*)vcE4.Get(Hnum.c_str());
  TH1F TE2ana = *(TH1F*)vcE2.Get(Hana.c_str());
  TH1F TE4ana = *(TH1F*)vcE4.Get(Hana.c_str());
  TH1F Tpyt = *(TH1F*)pyt.Get(Hnum.c_str());
  
  // Draw Analytic curve
  if (plotNum <= 3) {
    Tana->SetLineColor(1);
    Tana->SetLineStyle(1);
    Tana->SetLineWidth(2);
    Tana.Draw(styleAna.c_str());
  }
  else if (plotNum == 4) {
    TE2ana->SetLineColor(1);
    TE2ana->SetLineStyle(1);
    TE2ana->SetLineWidth(2);
    TE2ana.Draw(styleAna.c_str());
    TE4ana->SetLineColor(1);
    TE4ana->SetLineStyle(1);
    TE4ana->SetLineWidth(2);
    TE4ana.Draw(styleAna.c_str());
  }

  // Draw curves
  if (plotNum <= 2) {
    Tdef->SetLineColor(2);
    Tdef->SetLineStyle(1);
    Tdef->SetLineWidth(1);
    Tdef.Draw(styleAna.c_str());
  }
  if (plotNum == 1) {
    TpT->SetLineColor(4);
    TpT->SetLineStyle(2);
    TpT->SetLineWidth(2);
    TpT.Draw(styleAna.c_str());
  }
  else if (plotNum == 2) {
    Tmin->SetLineColor(2);
    Tmin->SetLineStyle(2);
    Tmin->SetLineWidth(1);
    Tmin.Draw(styleAna.c_str());
    Tmax->SetLineColor(2);
    Tmax->SetLineStyle(3);
    Tmax->SetLineWidth(1);
    Tmax.Draw(styleAna.c_str());
  } else if (plotNum == 3) {
    Tpyt->SetLineColor(14);
    Tpyt->SetLineStyle(1);
    Tpyt->SetLineWidth(1);
    Tpyt.Draw(styleAna.c_str());
    TpT2->SetLineColor(9);
    TpT2->SetLineStyle(3);
    TpT2->SetLineWidth(1);
    TpT2.Draw(styleAna.c_str());
    TpT->SetLineColor(4);
    TpT->SetLineStyle(2);
    TpT->SetLineWidth(2);
    TpT.Draw(styleAna.c_str());
  } else if (plotNum == 4) {
    TE2->SetLineColor(9);
    TE2->SetLineStyle(3);
    TE2->SetLineWidth(1);
    TE2.Draw(styleAna.c_str());
    TE4->SetLineColor(4);
    TE4->SetLineStyle(2);
    TE4->SetLineWidth(2);
    TE4.Draw(styleAna.c_str());
  }    

  // Draw Ariadne curve
  /*
  if (plotNum == 2) {
    Tari->SetLineColor(13);
    Tari->SetLineStyle(6);
    Tari->SetLineWidth(1);
    Tari.Draw(styleNum.c_str());
  }
  */

  // Make title
  double dx = xMax-xMin; 
  double xL1 = xMin+0.05*dx;
  double xR1 = xMax-0.05*dx;
  double x1  = xL1; 
  if (align == "R") x1=xR1;
  double dy = yMax-yMin;
  double y1  = yMin + 0.9*dy;
  double y2  = yMin + 0.82*dy;
  double y3  = yMin + 0.76*dy;
  double y4  = yMin + 0.08*dy;
  if (logy) {
    dy = log(yMax)-log(yMin);
    double logy1 = log(yMin)+0.9*dy;
    double logy2 = log(yMin)+0.82*dy;
    double logy3 = log(yMin)+0.76*dy;
    double logy4 = log(yMin)+0.08*dy;
    y1 = exp(logy1);
    y2 = exp(logy2);
    y3 = exp(logy3);    
    y4 = exp(logy4);    
  }
  
  TLatex *   tex = new TLatex(x1,y1,processTit.c_str());
  tex->SetTextSize(0.06);
  tex->SetLineWidth(2);
  tex->SetTextAlign(11);
  if (align == "R") tex->SetTextAlign(31);
  tex->Draw();
  tex = new TLatex(x1,y2,"Vincia 1.014 + Pythia 8.117");
  tex->SetTextAlign(11);
  if (align == "R") tex->SetTextAlign(31);
  tex->SetTextFont(42);
  tex->SetTextSize(0.04);
  tex->SetLineWidth(2);
  tex->Draw();
  tex = new TLatex(x1,y3,globalTit.c_str());
  if (align == "R") tex->SetTextAlign(31);
  tex->SetTextSize(0.044);
  tex->SetLineWidth(2);
  tex->SetTextAlign(12);
  if (align == "R") tex->SetTextAlign(32);
  tex->Draw();
  
  //Make legend  
  double yLeg = 0.45;
  if (plotNum >= 2 && plotNum != 4) yLeg=0.5;
  TLegend *leg = new TLegend(xLeg,0.24,xLegEnd,yLeg,NULL,"rNDC");

  leg->SetBorderSize(0);
  leg->SetFillStyle(0);
  string sVincia = "Vincia LL";
  
  TLegendEntry *entry;
  entry=leg->AddEntry("NULL","Analytic","l");
  Int_t ci;   // for color index setting
  entry->SetLineColor(1);
  entry->SetLineStyle(1);
  entry->SetLineWidth(2);
  entry->SetMarkerColor(2);
  entry->SetMarkerStyle(1);
  entry->SetMarkerSize(1);
  entry->SetTextAlign(12);
  entry->SetTextSize(0.04);
  entry->SetTextColor(1);

  if (plotNum <= 2) {
    if (plotNum == 1) sVincia += " (Q_{E} = m_{ant}^{2})";
    else sVincia += " (Ant=GGG)";

    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(2);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(1);
    entry->SetLineWidth(1);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
  } 
  
  if (plotNum == 1) {
    sVincia = "Vincia LL (Q_{E} = p_{T}^{2})";
    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(4);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(2);
    entry->SetLineWidth(2);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
  }
  else if (plotNum == 2) {
    sVincia = "Vincia LL (Ant=MIN)";
    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(2);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(2);
    entry->SetLineWidth(1);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
    sVincia = "Vincia LL (Ant=MAX)";
    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(2);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(3);
    entry->SetLineWidth(1);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
    /*
    sVincia = "Vincia LL_{Ariadne} (m_{ant}^{2})";
    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(2);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(3);
    entry->SetLineWidth(1);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
    */
  } else if (plotNum == 3) {
    sVincia = "Pythia 8 (Q_{E} = q_{T}^{2}, Q_{IR} = 2q_{Tcut})";
    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(14);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(1);
    entry->SetLineWidth(1);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
    sVincia = "Vincia LL (Q_{E} = p_{T}^{2}, Q_{IR} = 2p_{Tcut})";
    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(9);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(3);
    entry->SetLineWidth(1);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
    sVincia = "Vincia LL (Q_{E} = p_{T}^{2}, Q_{IR} = m_{cut})";
    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(4);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(2);
    entry->SetLineWidth(2);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
  } else if (plotNum == 4) {
    sVincia = "Vincia LL (Q_{0} = 100 GeV)";
    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(9);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(3);
    entry->SetLineWidth(1);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
    sVincia = "Vincia LL (Q_{0} = 10000 GeV)";
    entry=leg->AddEntry("NULL",sVincia.c_str(),"l");
    entry->SetLineColor(4);
    entry->SetFillStyle(0);
    entry->SetFillColor(0);
    entry->SetLineStyle(2);
    entry->SetLineWidth(2);
    entry->SetTextAlign(12);
    entry->SetTextSize(0.04);
    entry->SetTextColor(1);
  }

// Draw legend
  leg->Draw();

  // Write footnote
  string footnote;
  footnote="#alpha^{(0)}_{s} = 0.1, no g#rightarrow q#bar{q}";
  if (plotNum == 2 || plotNum == 4) footnote+=", Q_{E} = m_{ant}^{2}";
  if (plotNum != 4) {
    footnote+=", Q_{0} = 1000 GeV";
  }
  if (plotNum != 3) footnote+=", Q_{IR} = m_{cut} = 1 GeV";
  else footnote+=", Q_{IR} = 1 GeV";

  double xFoot = xMin + 0.5 * dx;
  tex = new TLatex(xFoot,y4,footnote.c_str());
  tex->SetTextSize(0.03);
  tex->SetLineWidth(2);
  tex->SetTextAlign(22);
  if (align == "L") tex->SetTextAlign(32);
  tex->Draw();


  //Update
  c1->Modified();
  c1->cd();
  c1->SetSelected(c1);

  // Print pretty pictures
   string outfile = "vincia-d";
   if (plotNum == 1) outfile +="1";
   if (plotNum == 2) outfile +="2";
   if (plotNum == 3) outfile +="3";
   if (plotNum == 4) outfile +="4";
   if (plotNum == 5) outfile +="5";
   if (plotNum == 6) outfile +="6";
   string jpgfile = outfile+".jpg";
   string pngfile = outfile+".png";
   string epsfile = outfile+".eps";
   string giffile = outfile+".gif";

   c1->Print(epsfile.c_str()); 
   c1->Print(jpgfile.c_str()); 
   c1->Print(pngfile.c_str()); 
   c1->Print(giffile.c_str()); 


}
